@@ -22,6 +22,10 @@
 
 ;;; Code:
 
+;; TODO: Consider deleting the list of links as a separate list at all, and
+;; instead store list of links as one of the entry's fields.  That is
+;; consistent with how we store active timestamps and keywords too.
+
 (eval-when-compile
   (require 'cl-lib)
   (require 'subr-x))
@@ -122,6 +126,7 @@ brackets."
 
 ;;; Links, citations and active timestamps
 
+(defvar org-mem-parser--found-keywords nil)
 (defvar org-mem-parser--found-links nil)
 (defvar org-mem-parser--found-active-stamps nil)
 (defconst org-mem-parser--org-ts-regexp
@@ -265,7 +270,13 @@ the subheading potentially has an ID of its own."
     (goto-char beg)
     (while (re-search-forward org-mem-parser--org-ts-regexp end t)
       (push (org-mem-parser--time-string-to-int (match-string 0))
-            org-mem-parser--found-active-stamps)))
+            org-mem-parser--found-active-stamps))
+
+    ;; Start over and look for #+keywords
+    (goto-char beg)
+    (setq org-mem-parser--found-keywords
+          (nconc (org-mem-parser--collect-keywords end)
+                 org-mem-parser--found-keywords)))
   (goto-char (or end (point-max))))
 
 
@@ -299,6 +310,28 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
       (forward-line 1))
     alist))
 
+
+;;; Keywords
+
+(defconst org-mem-parser--org-keyword-regexp "^[ 	]*#\\+\\(\\S-+?\\):[ 	]*\\(.*\\)$"
+  "Copy of `org-keyword-regexp'.")
+
+(defun org-mem-parser--merge-same-keywords (keywords)
+  "In alist KEYWORDS, de-dup the cars by appending the cdrs."
+  (let (new-alist)
+    (cl-loop for (key . value) in keywords
+             do (if-let* ((cell (assoc key new-alist)))
+                    (setcdr cell (append value (cdr cell)))
+                  (push (cons key value) new-alist)))
+    (cl-loop for cell in new-alist do (setcdr cell (reverse (cdr cell))))
+    (nreverse new-alist)))
+
+(defun org-mem-parser--collect-keywords (end)
+  "Search for #+KEYWORDS: until position END, and return an alist."
+  (cl-loop
+   while (re-search-forward org-mem-parser--org-keyword-regexp end t)
+   collect (cons (upcase (match-string 1)) (list (match-string 2)))))
+
 
 ;;; Main
 
@@ -353,7 +386,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
         (buffer-read-only t)
         bad-path
         found-entries
-        file-data
+        file-datum
         file-attr
         problem
         coding-system
@@ -386,7 +419,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
             (insert-file-contents file)
             (setq coding-system last-coding-system-used)
             ;; Better get the attributes now at the same time we read the file,
-            ;; in the off-chance it gets altered in the time between parsing
+            ;; on the off-chance it gets altered in the time between parsing
             ;; it and getting its attributes.
             (setq file-attr (file-attributes file 'integer)))
 
@@ -432,11 +465,6 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
             (save-excursion
               (when (re-search-forward org-mem-parser--outline-regexp nil t)
                 (narrow-to-region (point-min) (pos-bol))))
-            ;; A bug introduced in org-node 5035a33 (fixed ~5 days later)
-            ;; could insert BACKLINKS before PROPERTIES.  Add a warning so
-            ;; user can fix the affected notes.
-            (when (looking-at-p "^[ \t]*:BACKLINKS:[ \t]*$")
-              (error "Code 12: Found BACKLINKS drawer before PROPERTIES \(likely inserted by org-node 3.4.3, bug fixed in 3.4.4)"))
             ;; We can safely assume that if there's a properties drawer,
             ;; it's the first drawer AND it comes before any #+keyword, at
             ;; least going by the behavior of `org-id-get'.
@@ -462,6 +490,9 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
               (forward-line))
             (setq RIGHT (point)) ;; End of the "front matter".
 
+            ;; TODO: Instead of searching manually for #+title & #+filetags,
+            ;; use the info from `org-mem-parser--found-keywords' (which is
+            ;; populated by `org-mem-parser--scan-visible-text').
             (goto-char LEFT)
             (when (re-search-forward "^#\\+FILETAGS:" RIGHT t)
               (when (not (eolp))
@@ -522,13 +553,14 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
                         nil
                         TAGS
                         nil
-                        PSEUDO-ID)
+                        PSEUDO-ID
+                        (org-mem-parser--merge-same-keywords
+                         org-mem-parser--found-keywords))
                 found-entries)
 
           ;; Prep
           (unless CRUMBS
             (push (list 0 1 1 nil nil nil nil) CRUMBS))
-          (setq org-mem-parser--found-active-stamps nil)
           (setq LNUM (line-number-at-pos))
 
           ;; Loop over the file's headings
@@ -543,6 +575,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
                    (pos-bol)
                  (point-max))))
             (setq org-mem-parser--found-active-stamps nil)
+            (setq org-mem-parser--found-keywords nil)
             (setq STATS-COOKIES nil)
             (setq INITIAL-STATS-COOKIES nil)
             (setq CLOCK-LINES nil)
@@ -734,7 +767,9 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
                                      append (cl-sixth crumb))))
                           TAGS
                           TODO-STATE
-                          PSEUDO-ID)
+                          PSEUDO-ID
+                          (org-mem-parser--merge-same-keywords
+                           org-mem-parser--found-keywords))
                   found-entries)
             (goto-char (point-max))
             ;; NOTE: Famously slow `line-number-at-pos' fast in narrow region.
@@ -743,7 +778,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
 
           ;; Done analyzing this file.
           (cl-assert (eobp))
-          (setq file-data (list file
+          (setq file-datum (list file
                                 file-attr
                                 LNUM
                                 (point)
@@ -754,7 +789,7 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
       (( error )
        (widen)
        (setq problem (list (format-time-string "%H:%M") file (point) err (line-number-at-pos)))
-       (setq file-data (list file
+       (setq file-datum (list file
                              file-attr
                              (line-number-at-pos (point-max))
                              (point-max)
@@ -763,13 +798,13 @@ between buffer substrings \":PROPERTIES:\" and \":END:\"."
       ;; Catch fake `skip-file' signal.  Already caught real error signals.
       (t
        (cl-assert (null problem))
-       (cl-assert (null file-data))
+       (cl-assert (null file-datum))
        (cl-assert (null found-entries))
        (cl-assert (null org-mem-parser--found-links))))
 
     (list bad-path
           problem
-          file-data
+          file-datum
           found-entries
           org-mem-parser--found-links)))
 
