@@ -19,9 +19,9 @@
 ;; URL:      https://github.com/meedstrom/org-mem
 ;; Created:  2025-03-15
 ;; Keywords: text
-;; Package-Version: 0.31.3
-;; Package-Revision: 0.31.3-0-g444dc77d7f2b
-;; Package-Requires: ((emacs "29.1") (el-job "2.7.3") (llama "1.0") (truename-cache "0.1.2"))
+;; Package-Version: 0.34.0
+;; Package-Revision: 0.34.0-0-ga37b885c46b0
+;; Package-Requires: ((emacs "29.1") (el-job "2.7.3") (llama "1.0") (truename-cache "0.3.2"))
 
 ;;; Commentary:
 
@@ -42,7 +42,7 @@
 ;;; Code:
 
 (define-obsolete-variable-alias 'org-mem--bump-int 'org-mem-internal-version "2026-01-27 (after 0.26.4)")
-(defconst org-mem-internal-version 38 "Not a version number, but bumped sometimes.")
+(defconst org-mem-internal-version 43 "Not a version number, but bumped sometimes.")
 
 (require 'cl-lib)
 (require 'subr-x)
@@ -53,16 +53,12 @@
 
 (defvar org-id-locations)
 (defvar org-id-track-globally)
-(defvar org-id-locations-file)
 (defvar org-id-extra-files)
 (defvar org-id-files)
 (defvar org-element-cache-persistent)
 (defvar org-inhibit-startup)
 (defvar org-agenda-files)
-(declare-function org-id-locations-load "org-id")
-(declare-function org-id-locations-save "org-id")
 (declare-function org-id-alist-to-hash "org-id")
-(declare-function org-id-hash-to-alist "org-id")
 (declare-function org-before-first-heading-p "org")
 (declare-function org-entry-beginning-position "org")
 (declare-function org-entry-end-position "org")
@@ -70,6 +66,9 @@
 (unless (and (boundp 'el-job-internal-version)
              (>= el-job-internal-version 107))
   (display-warning 'org-mem "Update to el-job 2.7.3+ to use this version of org-mem"))
+(unless (and (boundp 'truename-cache-internal-version)
+             (>= truename-cache-internal-version 12))
+  (display-warning 'org-mem "Update to truename-cache 0.3.2+ to use this version of org-mem"))
 
 (defgroup org-mem nil "Fast info from a large amount of Org file contents."
   :group 'org)
@@ -91,7 +90,7 @@ If so, the text would only be available from the first time that
   :type 'boolean
   :package-version '(org-mem . "0.2.0"))
 
-(defcustom org-mem-do-look-everywhere nil
+(defcustom org-mem-do-look-everywhere t
   "Whether to infer directories from as many sources as possible.
 
 This means that any Org file found amongst...
@@ -108,21 +107,20 @@ will scan.  They won\\='t be scanned recursively.
 
 If Org has not yet loaded, only `recentf-list' is used."
   :type 'boolean
-  :package-version '(org-mem . "0.32.0"))
+  :package-version '(org-mem . "0.34.0"))
 
-(defcustom org-mem-do-sync-with-org-id nil
-  "Whether to exchange data with `org-id-locations'.
+(defcustom org-mem-do-sync-with-org-id t
+  "Whether to add seen org-ids to `org-id-locations'.
 
 Benefits:
-- Org-mem gets to know about files from anywhere, so long as they
-  contain some ID and can thus be found in `org-id-locations'.
-- Help ensure that ID-links to somewhere inside `org-mem-watch-dirs'
-  always work, so they never trigger a fallback attempt to run
-  `org-id-update-id-locations' when clicked, which can take a while.
+- Help ensure that ID-links always work, so they never trigger a
+  fallback attempt to run `org-id-update-id-locations' when clicked,
+  which can take a while.
 
-No effect until after Org has loaded."
+This variable used to have an additional effect similar to
+`org-mem-do-look-everywhere', but not since 0.34.0."
   :type 'boolean
-  :package-version '(org-mem . "0.6.0"))
+  :package-version '(org-mem . "0.34.0"))
 
 (defcustom org-mem-watch-dirs nil
   "List of directories in which to look for Org files.
@@ -133,32 +131,33 @@ Exceptions:
 
 - Subdirectories starting with underscore or dot, such as \".emacs.d\".
   To check such a directory, add its full path explicitly,
-  or else rely on `org-mem-do-sync-with-org-id' as additional source.
+  or else rely on `org-mem-do-look-everywhere' as additional source.
 - Subdirectories that are symlinks.
 - Anything matching `org-mem-exclude'.
 - Any file not ending in one of `org-mem-suffixes'.
 
-Can be left at nil, if `org-mem-do-sync-with-org-id' is t.
+Can be left at nil, if `org-mem-do-look-everywhere' is t.
 Benefits of configuring this anyway:
 
-- Awareness of files that contain no ID at all.
-- React when new files appear in these directories.
-  - Useful if this Emacs session is not the only program
-    that may create, move or rename files.
+- React when sub-directories that contained no Org file suddenly do,
+  such as on renaming a sub-directory.
 
-Tip: If past misconfiguration has recorded duplicate IDs,
-try command \\[org-mem-forget-id-locations-recursively]."
+This option used to be more important, but less since 0.34.0 when
+`org-mem-do-look-everywhere' (introduced in 0.32.0) defaults to t."
   :type '(repeat directory)
   :package-version '(org-mem . "0.5.0"))
 
-;; REVIEW: Use backslashes on Windows?
 (defcustom org-mem-exclude
   '("/logseq/bak/"
     "/logseq/version-files/"
     "/node_modules/"
     ".sync-conflict-" ;; Match e.g. "~/org/foo.sync-conflict-234234.org"
     "/backup" ;; Match e.g. "~/backups-2024/"
-    "/.#")
+    "/.#"
+    ;; These two are also hardcoded so it's moot, but hopefully we can stop
+    ;; hardcoding in the future.
+    "/."
+    "/_")
   "Literal substrings of file paths that should not be scanned.
 Aside from this variable, some filters are hard-coded:
 
@@ -166,6 +165,8 @@ Aside from this variable, some filters are hard-coded:
   - Thus backups ending in ~, # or similar are excluded in any case,
     under the default setting for that variable
 - We exclude symlinks
+- For historical reasons, \"/.\" and \"/_\" are also hard-coded,
+  so removing them here has no effect for now
 
 Main reason to configure this is to prevent counting various kinds of
 \"back-up\" and \"auto-save\" files as duplicate ID locations,
@@ -173,9 +174,12 @@ especially such files appearing somewhere inside `org-mem-watch-dirs'.
 
 You can also speed up `org-mem-reset' a bit by excluding directories
 found inside `org-mem-watch-dirs' with a very large amount of files
-\(on the order of 100,000), such as the infamous \"node_modules\"."
+\(on the order of 100,000), such as the infamous \"node_modules\".
+
+A folder with many \"*/.git/\" repositories, such as \"/elpaca/\",
+can also be good to exclude."
   :type '(repeat string)
-  :package-version '(org-mem . "0.15.1"))
+  :package-version '(org-mem . "0.32.0"))
 
 (defcustom org-mem-seek-link-types
   '("http" "https" "id" "file")
@@ -285,7 +289,7 @@ Note: All tables cleared often, meant for memoizations."
 (defun org-mem--get-file-metadata (file/entry/link)
   "Return list of assorted data if FILE/ENTRY/LINK known, else error."
   (let ((wild-file (if (stringp file/entry/link)
-                       (truename-cache-get-existed-p file/entry/link)
+                       (truename-cache-get-p file/entry/link)
                      (if (org-mem-entry-p file/entry/link)
                          (org-mem-entry-file-truename file/entry/link)
                        (if (org-mem-link-p file/entry/link)
@@ -324,38 +328,45 @@ Note: All tables cleared often, meant for memoizations."
   (tags-inherited        nil :read-only t :type list)
   (tags-local            nil :read-only t :type list)
   (todo-state            nil :read-only t :type string-or-nil)
-  (pseudo-id             -1  :read-only t :type integer        :documentation "Generated by `org-mem-parser--mk-id'.  Not `eq'-safe, use `=', `eql' or `equal'."))
+  (pseudo-id             -1  :read-only t :type integer        :documentation "Generated by `org-mem-parser--mk-id'.  Not `eq'-safe, use `=', `eql' or `equal'.")
+  (keywords              nil :read-only t :type list           :documentation "Alist of #+keywords: found in entry only.  See `org-mem-file-keywords'."))
 
 
 ;;; To find objects to operate on
 
+;; TODO: Add to context menu
 ;; This is the kind of thing I try not to have in org-mem, because look at all
 ;; the special-cases needed.  This one seems too useful to leave out, though.
-(defun org-mem-entry-at-point (&optional actually-file)
+(defun org-mem-entry-at-point (&optional actually-file interactive)
   "Return entry object near point in the current unmodified buffer.
 Only works if the buffer file has previously been scanned by org-mem.
 
 Optional argument ACTUALLY-FILE is for use in non-file-visiting
 buffers that presumably hold a copy of some file\\='s content,
-and then it should be the name of that file."
+and then it should be the name of that file.
+
+If INTERACTIVE, display the entry data using `org-mem-list-example'."
+  (interactive "i\np")
   (require 'org)
-  (when (buffer-modified-p)
-    (message "org-mem-entry-at-point: Results not guaranteed in a modified buffer"))
-  (unless (derived-mode-p 'org-mode)
-    (error "org-mem-entry-at-point: Buffer must be in org-mode"))
-  (let ((file (or actually-file (buffer-file-name (buffer-base-buffer))))
-        (id (org-entry-get nil "ID")))
-    (or (and id (org-mem-entry-by-id id))
-        (unless file
-          (error "org-mem-entry-at-point: Use in a file-visiting buffer or pass ACTUALLY-FILE"))
-        ;; May be better than `org-mem-entry-at-pos-in-file' if buffer modified.
-        (org-mem-entry-by-pseudo-id
-         (org-mem-parser--mk-id (file-attributes file)
-                                (buffer-substring (if (org-before-first-heading-p)
-                                                      (point-min)
-                                                    (org-entry-beginning-position))
-                                                  (org-entry-end-position))))
-        (org-mem-entry-at-pos-in-file (point) file))))
+  (if interactive
+      (org-mem-list-example (org-mem-entry-at-point actually-file))
+    (when (buffer-modified-p)
+      (message "org-mem-entry-at-point: Results not guaranteed in a modified buffer"))
+    (unless (derived-mode-p 'org-mode)
+      (error "org-mem-entry-at-point: Buffer must be in org-mode"))
+    (let ((file (or actually-file (buffer-file-name (buffer-base-buffer))))
+          (id (org-entry-get nil "ID")))
+      (or (and id (org-mem-entry-by-id id))
+          (unless file
+            (error "org-mem-entry-at-point: Use in a file-visiting buffer or pass ACTUALLY-FILE"))
+          ;; May be better than `org-mem-entry-at-pos-in-file' if buffer modified.
+          (org-mem-entry-by-pseudo-id
+           (org-mem-parser--mk-id (file-attributes file)
+                                  (buffer-substring (if (org-before-first-heading-p)
+                                                        (point-min)
+                                                      (org-entry-beginning-position))
+                                                    (org-entry-end-position))))
+          (org-mem-entry-at-pos-in-file (point) file)))))
 
 (defun org-mem-all-ids ()
   "All org-ids known to org-mem.
@@ -977,17 +988,23 @@ Can be nil."
 (defun org-mem-file-known-p (file)
   "Return non-nil when FILE is known to org-mem.
 Specifically, return the name by which it is known.
-This is more restrictive than `truename-cache-get-existed-p'
+This is more restrictive than `truename-cache-get-p'
 by only returning non-nil if the file has been scanned by org-mem."
   (cl-assert (stringp file))
   (or (and (gethash file org-mem--truename<>entries)
            file)
-      (and (setq file (truename-cache-get-existed-p file))
+      (and (setq file (truename-cache-get-p file))
            (if (gethash file org-mem--truename<>entries)
                file
              (truename-cache-invalidate file)
              nil))))
 
+(defun org-mem-file-keywords (file)
+  "Alist of all #+keywords: in FILE, as if from `org-collect-keywords'."
+  (with-memoization (org-mem--table 56 file)
+    (org-mem-parser--merge-same-keywords
+     (seq-mapcat #'org-mem-entry-keywords (org-mem-entries-in-file file)))))
+
 
 ;;; Optional: Roam aliases and refs
 
@@ -1105,7 +1122,7 @@ These link-targets are determined by `org-mem--split-roam-refs-field'."
   "Extract valid components of a ROAM-REFS field.
 What is valid?  See \"org-mem-test.el\"."
   (when roam-refs
-    (with-current-buffer (get-buffer-create " *org-mem-scratch*" t)
+    (with-current-buffer (get-buffer-create " *org-mem-fundamental-scratch*" t)
       (erase-buffer)
       (insert roam-refs)
       (goto-char 1)
@@ -1234,12 +1251,14 @@ Like `org-mem-entry-title', this always returns a string."
   (:method ((xx org-mem-entry)) (org-mem-entry-title-maybe xx))
   (:method ((xx string)) (org-mem-file-title-strict xx)))
 
-(defun org-mem-entries-in (file/files)
-  "All entries in FILE/FILES."
-  (funcall (if (listp file/files)
-               #'org-mem-entries-in-files
-             #'org-mem-entries-in-file)
-           file/files))
+(defun org-mem-entries-in (file/files/entry)
+  "All entries in FILE/FILES/ENTRY."
+  (funcall (if (org-mem-entry-p file/files/entry)
+               #'org-mem-entry-children
+             (if (listp file/files/entry)
+                 #'org-mem-entries-in-files
+               #'org-mem-entries-in-file))
+           file/files/entry))
 
 
 ;;; Core logic
@@ -1356,7 +1375,6 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
           (message nil)
           (redisplay))))))
 
-(defvar org-mem--caused-retry nil)
 (defun org-mem--finalize-full-scan (parse-results)
   "Handle PARSE-RESULTS from `org-mem--scan-full'."
   (run-hook-with-args 'org-mem-pre-full-scan-functions parse-results)
@@ -1367,15 +1385,15 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
   (clrhash org-mem--truename<>entries)
   (clrhash org-mem--pseudo-id<>links)
   (setq org-mem--title-collisions nil)
-  (let ((bad-paths (cl-loop for (bad) in parse-results when bad collect bad))
-        problems)
-    (org-mem--invalidate-file-names bad-paths)
+  (let (problems)
     ;; Build tables.
-    (with-current-buffer (get-buffer-create " *org-mem-scratch*" t)
-      (cl-loop for (_ problem file-data entries links) in parse-results do
+    (with-current-buffer (get-buffer-create " *org-mem-fundamental-scratch*" t)
+      (cl-loop for (bad-path problem file-datum entries links) in parse-results do
+               (when bad-path (truename-cache-invalidate bad-path))
                (when problem (push problem problems))
-               (puthash (car file-data) file-data org-mem--truename<>metadata)
-               (run-hook-with-args 'org-mem--record-file-functions file-data)
+               (when file-datum
+                 (puthash (car file-datum) file-datum org-mem--truename<>metadata)
+                 (run-hook-with-args 'org-mem--record-file-functions file-datum))
                (dolist (entry entries)
                  (org-mem--record-entry entry)
                  (run-hook-with-args 'org-mem--record-entry-functions entry))
@@ -1411,11 +1429,6 @@ overrides a default message printed when `org-mem-do-cache-text' is t."
     ;; Other stuff.
     (while org-mem-initial-scan-hook
       (funcall (pop org-mem-initial-scan-hook)))
-    (when bad-paths
-      ;; Scan again, but guard against repeating forever.
-      (unless (seq-intersection bad-paths org-mem--caused-retry)
-        (setq org-mem--caused-retry (append bad-paths org-mem--caused-retry))
-        (org-mem--scan-full)))
     (when (and org-mem--title-collisions org-mem-do-warn-title-collisions)
       (message "Some IDs share title, see M-x org-mem-list-title-collisions"))
     (when problems
@@ -1464,7 +1477,7 @@ remove, it's easiest to wipe and re-build."
 
 (defun org-mem--maybe-snitch-to-org-id (entry)
   "Add applicable ENTRY data to `org-id-locations'.
-No-op if Org has not loaded."
+No-op if `org-mem-do-sync-with-org-id' is nil or Org has not loaded."
   (when (and org-mem-do-sync-with-org-id
              (org-mem-entry-id entry)
              (featurep 'org-id)
@@ -1473,17 +1486,16 @@ No-op if Org has not loaded."
              (org-mem-entry-file entry)
              org-id-locations)))
 
-;; This is non-essential, as org-id works as intended anyway,
-;; but other libraries may assume that `org-id-files' is kept up to date.
-(defun org-mem--reset-org-id-files (_)
+(defun org-mem--reset-org-id-files (&rest _)
   "Set `org-id-files' to reflect the set of files in `org-id-locations'.
-Or no-op, if `org-mem-do-sync-with-org-id' is nil."
+No-op if `org-mem-do-sync-with-org-id' is nil or Org has not loaded."
   (when (and org-mem-do-sync-with-org-id
              (featurep 'org-id)
              (org-mem--try-ensure-org-id-table-p))
     (setq org-id-files (delete-dups (hash-table-values org-id-locations)))))
 
-(add-hook 'org-mem-post-full-scan-functions #'org-mem--reset-org-id-files)
+(add-hook 'org-mem-post-full-scan-functions #'org-mem--reset-org-id-files -10)
+(add-hook 'org-mem-post-targeted-scan-functions #'org-mem--reset-org-id-files -10)
 
 (defun org-mem--mk-work-vars ()
   "Make alist of variables needed by `org-mem-parser--parse-file'."
@@ -1534,20 +1546,6 @@ Or no-op, if `org-mem-do-sync-with-org-id' is nil."
 
 ;;; File discovery subroutines
 
-(defun org-mem--invalidate-file-names (bad-names)
-  "Scrub bad file names BAD-NAMES in the truename cache.
-Notably, invalidate part of the cache used by `org-mem-file-known-p'.
-If `org-mem-do-sync-with-org-id' t, also scrub `org-id-locations'."
-  (let ((invalidated (seq-mapcat #'truename-cache-invalidate bad-names)))
-    (when (and invalidated
-               org-mem-do-sync-with-org-id
-               (org-mem--try-ensure-org-id-table-p))
-      (setq org-id-locations
-            (org-id-alist-to-hash
-             (cl-loop for cell in (org-id-hash-to-alist org-id-locations)
-                      unless (member (car cell) invalidated)
-                      collect cell))))))
-
 (defun org-mem--try-ensure-org-id-table-p ()
   "Coerce `org-id-locations' into hash table form, return nil on fail."
   (require 'org-id)
@@ -1570,7 +1568,6 @@ For that, you may be looking for `org-mem-all-files'.
 
 Affected by user options:
 - `org-mem-watch-dirs'
-- `org-mem-do-sync-with-org-id'
 - `org-mem-do-look-everywhere'
 - `org-mem-suffixes'
 - `org-mem-exclude'"
@@ -1594,21 +1591,20 @@ Affected by user options:
                          (bound-and-true-p recentf-list)))
         (and org-mem-do-look-everywhere
              (featurep 'org)
-             (append (org-files-list)
-                     ;; Should've been a separate option
-                     (if (stringp (car org-agenda-text-search-extra-files))
-                         org-agenda-text-search-extra-files
-                       (cdr org-agenda-text-search-extra-files))))
-        (and (or org-mem-do-sync-with-org-id
-                 org-mem-do-look-everywhere)
+             (nconc (org-files-list)
+                    ;; Should've been a separate option
+                    (if (stringp (car org-agenda-text-search-extra-files))
+                        org-agenda-text-search-extra-files
+                      (cdr org-agenda-text-search-extra-files))))
+        (and org-mem-do-look-everywhere
              (featurep 'org-id)
-             (append (seq-filter #'stringp
+             org-id-track-globally
+             (nconc (seq-filter #'stringp
                                  ;; Should've been a separate option
                                  (if (symbolp org-id-extra-files)
                                      (symbol-value org-id-extra-files)
                                    org-id-extra-files))
-                     (and (org-mem--try-ensure-org-id-table-p)
-                          (hash-table-values org-id-locations))))))
+                     org-id-files))))
    when (and (string-match-p suffix-re (car cell))
              (not (string-match-p exclude-re (car cell))))
    collect cell))
@@ -1616,18 +1612,14 @@ Affected by user options:
 (defun org-mem--check-user-settings ()
   "Signal if user options are set to illegal or inefficient values."
   (unless (or org-mem-watch-dirs
-              org-mem-do-sync-with-org-id
               org-mem-do-look-everywhere)
     (user-error "At least one of these settings must be non-nil:
 `org-mem-watch-dirs'
-`org-mem-do-sync-with-org-id'
 `org-mem-do-look-everywhere'"))
   (unless (compiled-function-p (symbol-function #'org-mem--truenames-and-attrs))
     (display-warning 'org-mem "Org-mem will be very slow unless compiled"))
   (unless (compiled-function-p (symbol-function #'truename-cache-collect-files-and-attributes))
     (display-warning 'org-mem "Org-mem will be very slow unless truename-cache is compiled"))
-  (when (and org-mem-do-sync-with-org-id (featurep 'org-id) (not org-id-track-globally))
-    (user-error "If org-mem-do-sync-with-org-id is t, org-id-track-globally must be t as well"))
   (when (seq-find #'file-remote-p org-mem-watch-dirs)
     (user-error "Must not contain remote directories: org-mem-watch-dirs")))
 
@@ -1653,17 +1645,15 @@ corresponding to your package name."
 ;; to use with `org-mem-entry-text' to generate backlink previews, for
 ;; example, and it is apparently rare to realize the perf impact of
 ;; opening many Org buffers.
-;; Maybe if Org doesn't fix or can't fix the startup perf, they can ship an
-;; "org-scratch" function like this?  It belongs upstream.
-(defun org-mem-org-mode-scratch (&optional bufname)
+(defun org-mem-scratch (&optional bufname)
   "Get or create a hidden `org-mode' buffer.
 Ignore `org-mode-hook' and startup options.
 
 Like a temp buffer, but does not clean up.
 You should probably use `erase-buffer' in case it already contains text.
-BUFNAME defaults to \" *org-mem-org-mode-scratch*\"."
+BUFNAME defaults to \" *org-mem-scratch*\"."
   (require 'org)
-  (setq bufname (or bufname " *org-mem-org-mode-scratch*"))
+  (setq bufname (or bufname " *org-mem-scratch*"))
   (or (get-buffer bufname)
       (let ((org-inhibit-startup t)
             (org-agenda-files nil)
@@ -1676,15 +1666,17 @@ BUFNAME defaults to \" *org-mem-org-mode-scratch*\"."
 
 (defun org-mem-fontify-like-org (string)
   "Return STRING with text properties from fontifying it in `org-mode'."
-  (with-current-buffer (org-mem-org-mode-scratch)
+  (declare (obsolete nil "0.32.0 (2026-02-27)"))
+  (with-current-buffer (org-mem-scratch)
     (erase-buffer)
     (insert string)
     (font-lock-ensure)
     (buffer-string)))
 
 (defun org-mem-tip-if-empty ()
+  "If tables empty, print a helpful message."
   (when (hash-table-empty-p org-mem--truename<>metadata)
-    (let ((msg (if org-mem-do-sync-with-org-id
+    (let ((msg (if org-mem-do-look-everywhere
                    (if (not (featurep 'org-id))
                        (if org-mem-watch-dirs
                            "org-mem: No files found in `org-mem-watch-dirs', and no org-ids because Org not loaded"
@@ -1722,53 +1714,6 @@ Old style was single list of 5 lists, representing all files combined:
    append links into all-links
    finally return (list badpaths fdata all-entries all-links problems)))
 
-
-
-;;; End-user tool
-
-(defun org-mem-forget-id-locations-recursively (dir)
-  "Remove all references in `org-id-locations' to any files under DIR.
-
-Note that if DIR descends from a member of `org-mem-watch-dirs',
-this action may make no practical impact unless you also add DIR to
-`org-mem-exclude'.
-This is because with `org-mem-do-sync-with-org-id' t, they simply get
-added again on next scan.
-
-Tip: In case of unsolvable problems, eval this to thoroughly wipe
-org-id-locations:
-
-\(progn
-  (delete-file org-id-locations-file)
-  (setq org-id-locations nil)
-  (setq org-id--locations-checksum nil)
-  (setq org-agenda-text-search-extra-files nil)
-  (setq org-id-files nil)
-  (setq org-id-extra-files nil))"
-  (interactive "DForget all IDs recursively in directory: ")
-  (require 'org-id)
-  (let ((files (org-mem--dir-files-recursive dir org-mem-suffixes nil)))
-    (when files
-      (setq files (append files (seq-keep #'truename-cache-get-existed-p files)))
-      (message "Forgetting all IDs in directory %s..." dir)
-      (redisplay t)
-      (maphash (lambda (id file)
-                 (when (member file files)
-                   (remhash id org-mem--id<>entry)
-                   (remhash id org-id-locations)))
-               org-id-locations)
-      ;; Bonus, probably unnecessary
-      (dolist (file files)
-        (dolist (entry (gethash file org-mem--truename<>entries))
-          (remhash (org-mem-entry-pseudo-id entry)
-                   org-mem--pseudo-id<>links))
-        (remhash file org-mem--truename<>entries)
-        (remhash file org-mem--truename<>metadata))
-      (setq org-id-files (cl-nset-difference org-id-files files :test #'equal))
-      (org-id-locations-save)
-      (message "Forgetting all IDs in directory %s...done" dir)
-      (org-mem--scan-full))))
-
 
 (defmacro org-mem--def-whiny-alias (old new when removed-by)
   "Define function OLD as effectively an alias for NEW.
@@ -1780,7 +1725,7 @@ may be removed from the package."
        (declare (obsolete ,(cadr new) ,when))
        (unless checked-once
          (setq checked-once t)
-         (lwarn ,old :warning "Obsolete since %s, will be removed by %s; use `%s' instead. (Check your initfiles)"
+         (lwarn ,old :warning "Obsolete since %s, will be removed by %s; use `%s' instead. "
                 ,when ,removed-by ,new))
        (apply ,new args))))
 
@@ -1815,9 +1760,10 @@ Still exists under name `org-mem--record-file-functions',
 but please use `org-mem-post-full-scan-functions'.")
 
 (define-obsolete-function-alias 'org-mem-entry-that-contains-link #'org-mem-link-entry "0.29.0 (2026-02-11)")
+(define-obsolete-function-alias 'org-mem-org-mode-scratch #'org-mem-scratch "0.32.0 (2026-02-27)")
 
 (defun org-mem--list-files-from-fs ()
-  (declare (obsolete nil "2026-02-16"))
+  (declare (obsolete nil "0.32.0 (2026-02-27)"))
   (mapcar #'car (org-mem--truenames-and-attrs)))
 
 (provide 'org-mem)
